scitex_dataset API Reference
============================

.. automodule:: scitex_dataset
   :members:
   :undoc-members:
   :show-inheritance:

Search Module
-------------

.. automodule:: scitex_dataset.search
   :members:
   :undoc-members:
   :show-inheritance:

Database Module
---------------

.. automodule:: scitex_dataset.database
   :members:
   :undoc-members:
   :show-inheritance:

Neuroscience Sources
--------------------

OpenNeuro
~~~~~~~~~

.. automodule:: scitex_dataset.neuroscience.openneuro
   :members:
   :undoc-members:
   :show-inheritance:

DANDI
~~~~~

.. automodule:: scitex_dataset.neuroscience.dandi
   :members:
   :undoc-members:
   :show-inheritance:

PhysioNet
~~~~~~~~~

.. automodule:: scitex_dataset.neuroscience.physionet
   :members:
   :undoc-members:
   :show-inheritance:

General Sources
---------------

Zenodo
~~~~~~

.. automodule:: scitex_dataset.general.zenodo
   :members:
   :undoc-members:
   :show-inheritance:

CLI
---

.. automodule:: scitex_dataset._cli
   :members:
   :undoc-members:
   :show-inheritance:
